==> dl.php?src=linea21_2_0_0.zip: linea21/languages/en/lang_yellowpages.utf-8.php <==
<?php
/**
 * @package linea21\languages\en
 * @author $Author$ - linea21 <info@linea21.com> & Stéphanie Loubechine
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



$lang['yp']['section'] = "organisations directory";

/*	nommage des modules
 *  	*/
$lang['yp']['name']="organisation";
$lang['yp']['confirm_add'] = "organisation successfully added\n";
$lang['yp']['confirm_mod'] = "organisation successfully updated\n";
$lang['yp']['confirm_sup'] ="organisation successfully deleted\n";
$lang['yp']['confirm_pub']= "organisation successfully added, your registration will be validated soon by an administrator";
$lang['yp']['confirm_pub2']= "Click me to go back to the directory";
/*	nommage rubrique module
 *  	*/
$lang['yp']['add']= "Add a new ".$lang['yp']['name'];
$lang['yp']['mod']= "Edit ".$lang['yp']['name'];
$lang['yp']['sup']= "Delete ".$lang['yp']['name'];
$lang['yp']['det']= ucfirst($lang['yp']['name']) . " details";
$lang['yp']['list']= "View the directory ";
$lang['yp']['nb_total']='registered organisations';

/*	publique
 *  	*/
$lang['yp']['add_public']= "Add your ".$lang['yp']['name'];
$lang['yp']['h1_public_comment']='All organisations related to sustainable development and '. SITE_NAME.' are listed in our directory. If you want to appear on our directory, click the "add your organisation." link and enter your data';
$lang['yp']['h1_public_add']='The registration of your organisation is free, fill out the form below, you will receive an email when your registration will be effective (administrator validation required)';


/*	nommage rubrique add / mod /det
 *  	*/
$lang['yp']['add_title']="Add data about the new ".$lang['yp']['name'];
$lang['yp']['mod_title']="Edit data about ".$lang['yp']['name'];
$lang['yp']['recap_commment']="no comment";
$lang['yp']['confirmation']="confirm subscription";
$lang['yp']['actions']='actions';


/*	nommage email
 *  	*/


$lang['yp']['mail_body1']="Your registration is now confirmed. You can access the entry by following this link : ";
$lang['yp']['confirm_subscription']='Your organisation is now listed in the directory';
$lang['yp']['mail_subject_added']="Your organisation has been added to the directory";
$lang['yp']['mail_body_added1']="We added your organisation in our directory.<br /><br />\n\nYou can access it by following the URL : ";
$lang['yp']['mail_body_added2']="If you want us to remove the entry please contact us.\n";


/*	nommage rubrique sup
 *  	*/
$lang['yp']['sup_yp_warning']="Do you really want to delete this ".$lang['yp']['name']." ?";


/*	nommage élément rubrique
 *  	*/

$lang['yp']['name2']="name";
$lang['yp']['activity']="activity";
$lang['yp']['street']="street";
$lang['yp']['postal_code']="postal code";
$lang['yp']['infos_adresse']="postal address and complementary informations";
$lang['yp']['adresse']="address";
$lang['yp']['city']="city";
$lang['yp']['country']="country";
$lang['yp']['phone']="phone number";
$lang['yp']['fax']="fax number";
$lang['yp']['email']="email";
$lang['yp']['website']="website";
$lang['yp']['level']="associated level";


/*	nommage quickbox
 *  	*/
$lang['yp']['qb_title']=" latest modifications";


/*	divers
 *  	*/
$lang['yp']['select_choice']="-- Choose in this list --";
$lang['yp']['facultatif']="optional";
$lang['yp']['nolevel']="No level";
$lang['yp']['title_level']="organisations with level";
$lang['yp']['title_statut']="organisations with status";
$lang['yp']['statut_filter']="Display by status";
$lang['yp']['preinscription']="Show pre-registrations";
$lang['yp']['all']="Show full directory";
$lang['yp']['draft']="pre-registered";
$lang['yp']['noresult']="There is no organisation with this criteria.";
$lang['yp']['alphabetical']=' [A-Z] ';


/*	messages
 *  	*/


$lang['yp']['object_notname']="Name is required.";
$lang['yp']['object_notactivity']="Activity is required.";
$lang['yp']['object_notstreet']="Street is required.";
$lang['yp']['object_notpostal_code']="Postal code is required.";
$lang['yp']['object_notcity']="City is required.";
$lang['yp']['object_notcountry']="Country is required.";
$lang['yp']['object_notemail']="Given mail is not valid.";
$lang['yp']['object_notphone']="Given phone number is not valid.";
$lang['yp']['object_notfax']="Given fax number is not valid.";
$lang['yp']['invalid_protocol']='Invalid protocol, please check URL syntax';


/*	rubrique d'aide
 *  	*/
$lang['yp']['help_add1']="To add a new organisation, please insert the required informations in the form above";
$lang['yp']['help_add2']="After submitting the form, check your data in the summary";
$lang['yp']['help_add3']='After checking summary, click the \'review settings\' button to make changes';


$lang['yp']['help_list1']="Click on organisation titles to display more informations";
$lang['yp']['help_list2']="Delete organisation by clicking on the delete icon linked in";
$lang['yp']['help_list3']="Edit organisation by clicking on the edit icon linked in";
$lang['yp']['help_list4']="To add a new organisation, please insert the required informations in the form above";
$lang['yp']['help_list5']="To perform search on organisations directory only, just click the 'search' link";
$lang['yp']['help_list6']="You can display pre-registered organisations by clicking the 'Show pre-registrations' link";
$lang['yp']['help_list7']="Click the dedicated link to validate a pre-registration";
//$lang['yp']['help_list8']="Vous pouvez afficher les organisations triées par thème en sélectionnant un thème dans  \"afficher par thème\"";
$lang['yp']['help_list9']="Filter by status to display organisation for a specific status";
$lang['yp']['help_list10']="Archive status allow you to keep organisations in the directory with no public access.";




$lang['yp']['help_mod1']="To edit an organisation, please insert the required informations in the form above";

$lang['yp']['help_mod2']="Once the form submitted, check your data in the summary";
$lang['yp']['help_mod3']='After checking summary, click the \'review settings\' button to make changes';
$lang['yp']['help_mod4']="Archive status allow you to keep organisations in the directory with no public access.";




$lang['yp']['help_det1']="Edit organisation by clicking on the edit icon linked in";
$lang['yp']['help_det2']="Delete organisation by clicking on the delete icon linked in";
$lang['yp']['help_det3']="Click on organisation level to display more informations about this level";
$lang['yp']['help_det4']="Click 'validate pre-registration' link to add organisation to the directory, an email will be automatically addressed to the organisation";


$lang['yp']['help_sup1']="organisation will be deleted by clicking the 'validate' button";
$lang['yp']['help_sup2']="Also delete pre-registration from this page";
?>

==> dl.php?src=linea21_2_3_0.zip: linea21/languages/en/lang_yellowpages.utf-8.php <==
<?php
/**
 * @package linea21\languages\en
 * @author $Author$ - linea21 <info@linea21.com> & Stéphanie Loubechine
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



$lang['yp']['section'] = "organisations directory";

/*	nommage des modules
 *  	*/
$lang['yp']['name']="organisation";
$lang['yp']['confirm_add'] = "organisation successfully added\n";
$lang['yp']['confirm_mod'] = "organisation successfully updated\n";
$lang['yp']['confirm_sup'] ="organisation successfully deleted\n";
$lang['yp']['confirm_pub']= "organisation successfully added, your registration will be validated soon by an administrator";
$lang['yp']['confirm_pub2']= "Click me to go back to the directory";
/*	nommage rubrique module
 *  	*/
$lang['yp']['add']= "Add a new ".$lang['yp']['name'];
$lang['yp']['mod']= "Edit ".$lang['yp']['name'];
$lang['yp']['sup']= "Delete ".$lang['yp']['name'];
$lang['yp']['det']= ucfirst($lang['yp']['name']) . " details";
$lang['yp']['list']= "View the directory ";
$lang['yp']['nb_total']='registered organisations';

/*	publique
 *  	*/
$lang['yp']['add_public']= "Add your ".$lang['yp']['name'];
$lang['yp']['h1_public_comment']='All organisations related to sustainable development and '. SITE_NAME.' are listed in our directory. If you want to appear on our directory, click the "add your organisation." link and enter your data';
$lang['yp']['h1_public_add']='The registration of your organisation is free, fill out the form below, you will receive an email when your registration will be effective (administrator validation required)';


/*	nommage rubrique add / mod /det
 *  	*/
$lang['yp']['add_title']="Add data about the new ".$lang['yp']['name'];
$lang['yp']['mod_title']="Edit data about ".$lang['yp']['name'];
$lang['yp']['recap_commment']="no comment";
$lang['yp']['confirmation']="confirm subscription";
$lang['yp']['actions']='actions';


/*	nommage email
 *  	*/


$lang['yp']['mail_body1']="Your registration is now confirmed. You can access the entry by following this link : ";
$lang['yp']['confirm_subscription']='Your organisation is now listed in the directory';
$lang['yp']['mail_subject_added']="Your organisation has been added to the directory";
$lang['yp']['mail_body_added1']="We added your organisation in our directory.<br /><br />\n\nYou can access it by following the URL : ";
$lang['yp']['mail_body_added2']="If you want us to remove the entry please contact us.\n";


/*	nommage rubrique sup
 *  	*/
$lang['yp']['sup_yp_warning']="Do you really want to delete this ".$lang['yp']['name']." ?";


/*	nommage élément rubrique
 *  	*/

$lang['yp']['name2']="name";
$lang['yp']['activity']="activity";
$lang['yp']['street']="number / street";
$lang['yp']['postal_code']="postal code";
$lang['yp']['infos_adresse']="postal address and complementary informations";
$lang['yp']['adresse']="address";
$lang['yp']['city']="city";
$lang['yp']['country']="country";
$lang['yp']['phone']="phone number";
$lang['yp']['fax']="fax number";
$lang['yp']['email']="email";
$lang['yp']['website']="website";
$lang['yp']['level']="associated level";


/*	nommage quickbox
 *  	*/
$lang['yp']['qb_title']=" latest modifications";


/*	divers
 *  	*/
$lang['yp']['select_choice']="-- Choose in this list --";
$lang['yp']['facultatif']="optional";
$lang['yp']['nolevel']="No level";
$lang['yp']['title_level']="organisations with level";
$lang['yp']['title_statut']="organisations with status";
$lang['yp']['statut_filter']="Display by status";
$lang['yp']['preinscription']="Show pre-registrations";
$lang['yp']['all']="Show full directory";
$lang['yp']['draft']="pre-registered";
$lang['yp']['noresult']="There is no organisation with this criteria.";
$lang['yp']['alphabetical']=' [A-Z] ';


/*	messages
 *  	*/


$lang['yp']['object_notname']="Name is required.";
$lang['yp']['object_notactivity']="Activity is required.";
$lang['yp']['object_notstreet']="Street is required.";
$lang['yp']['object_notpostal_code']="Postal code is required.";
$lang['yp']['object_notcity']="City is required.";
$lang['yp']['object_notcountry']="Country is required.";
$lang['yp']['object_notemail']="Given mail is not valid.";
$lang['yp']['object_notphone']="Given phone number is not valid.";
$lang['yp']['object_notfax']="Given fax number is not valid.";
$lang['yp']['invalid_protocol']='Invalid protocol, please check URL syntax';


/*	rubrique d'aide
 *  	*/
$lang['yp']['help_add1']="To add a new organisation, please insert the required informations in the form above";
$lang['yp']['help_add2']="After submitting the form, check your data in the summary";
$lang['yp']['help_add3']='After checking summary, click the \'review settings\' button to make changes';


$lang['yp']['help_list1']="Click on organisation titles to display more informations";
$lang['yp']['help_list2']="Delete organisation by clicking on the delete icon linked in";
$lang['yp']['help_list3']="Edit organisation by clicking on the edit icon linked in";
$lang['yp']['help_list4']="To add a new organisation, please insert the required informations in the form above";
$lang['yp']['help_list5']="To perform search on organisations directory only, just click the 'search' link";
$lang['yp']['help_list6']="You can display pre-registered organisations by clicking the 'Show pre-registrations' link";
$lang['yp']['help_list7']="Click the dedicated link to validate a pre-registration";
//$lang['yp']['help_list8']="Vous pouvez afficher les organisations triées par thème en sélectionnant un thème dans  \"afficher par thème\"";
$lang['yp']['help_list9']="Filter by status to display organisation for a specific status";
$lang['yp']['help_list10']="Archive status allow you to keep organisations in the directory with no public access.";




$lang['yp']['help_mod1']="To edit an organisation, please insert the required informations in the form above";

$lang['yp']['help_mod2']="Once the form submitted, check your data in the summary";
$lang['yp']['help_mod3']='After checking summary, click the \'review settings\' button to make changes';
$lang['yp']['help_mod4']="Archive status allow you to keep organisations in the directory with no public access.";




$lang['yp']['help_det1']="Edit organisation by clicking on the edit icon linked in";
$lang['yp']['help_det2']="Delete organisation by clicking on the delete icon linked in";
$lang['yp']['help_det3']="Click on organisation level to display more informations about this level";
$lang['yp']['help_det4']="Click 'validate pre-registration' link to add organisation to the directory, an email will be automatically addressed to the organisation";


$lang['yp']['help_sup1']="organisation will be deleted by clicking the 'validate' button";
$lang['yp']['help_sup2']="Also delete pre-registration from this page";
?>
